@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
``dob-viewer`` — ``/tests/fixtures/*``
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@

NOTE: This directory, ``tests/fixtures/``, and the files thereunder,
e.g., ``test-import-fixture.rst``, are shared between the two ``dob*``
packages that use the Facts Carousel, ``dob-viewer`` and ``dob``.
(The fixture is mostly for ``dob-viewer``, but ``dob`` has a few hacky tests
that need to fire up a real Carousel, such as ``test_write_facts_file.py``.)

